@@ -13,9 +13,9 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-topic-action-group.h 6588 2006-09-13 11:34:25Z chpe $
+ *  $Id$
  */
 
 #ifndef EPHY_TOPIC_ACTION_GROUP_H
@@ -24,8 +24,7 @@
 #include "ephy-link-action.h"
 #include "ephy-node.h"
 
-#include <gtk/gtkactiongroup.h>
-#include <gtk/gtkuimanager.h>
+#include <gtk/gtk.h>
 
 G_BEGIN_DECLS
 
