@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- *  $Id: ephy-go-action.c 7072 2007-06-05 20:20:24Z diegoe $
+ *  $Id$
  */
 
 #include "config.h"
@@ -25,40 +25,11 @@
 #include "ephy-debug.h"
 
 #include <glib/gi18n.h>
-#include <gtk/gtktoolitem.h>
-#include <gtk/gtkbutton.h>
+#include <gtk/gtk.h>
 
 static void ephy_go_action_class_init (EphyGoActionClass *class);
 
-static GObjectClass *parent_class = NULL;
-
-GType
-ephy_go_action_get_type (void)
-{
-	static GType type = 0;
-
-	if (G_UNLIKELY (type == 0))
-	{
-		const GTypeInfo type_info =
-		{
-			sizeof (EphyGoActionClass),
-			(GBaseInitFunc) NULL,
-			(GBaseFinalizeFunc) NULL,
-			(GClassInitFunc) ephy_go_action_class_init,
-			(GClassFinalizeFunc) NULL,
-			NULL,
-			sizeof (EphyGoAction),
-			0, /* n_preallocs */
-			(GInstanceInitFunc) NULL,
-		};
-
-		type = g_type_register_static (EPHY_TYPE_LINK_ACTION,
-					       "EphyGoAction",
-					       &type_info, 0);
-	}
-
-	return type;
-}
+G_DEFINE_TYPE (EphyGoAction, ephy_go_action, EPHY_TYPE_LINK_ACTION)
 
 static GtkWidget *
 create_tool_item (GtkAction *action)
@@ -78,20 +49,22 @@ create_tool_item (GtkAction *action)
 	return item;
 }
 
-static void
+static gboolean
 button_clicked_cb (GtkWidget *widget,
 		   GdkEventButton *event,
 		   gpointer user_data)
 {
 	if (event->button == 1 || event->button == 2)
 		gtk_action_activate (GTK_ACTION (user_data));
+	
+	return FALSE;
 }
 
 static void
 connect_proxy (GtkAction *action,
 	       GtkWidget *proxy)
 {      
-	GTK_ACTION_CLASS (parent_class)->connect_proxy (action, proxy);
+	GTK_ACTION_CLASS (ephy_go_action_parent_class)->connect_proxy (action, proxy);
 
 	if (GTK_IS_TOOL_ITEM (proxy))
 	{
@@ -108,7 +81,7 @@ disconnect_proxy (GtkAction *action,
 	g_signal_handlers_disconnect_by_func
 		(proxy, G_CALLBACK (gtk_action_activate), action);
 
-	GTK_ACTION_CLASS (parent_class)->disconnect_proxy (action, proxy);
+	GTK_ACTION_CLASS (ephy_go_action_parent_class)->disconnect_proxy (action, proxy);
 }
 
 static void
@@ -116,9 +89,14 @@ ephy_go_action_class_init (EphyGoActionClass *class)
 {
 	GtkActionClass *action_class = GTK_ACTION_CLASS (class);
 
-	parent_class = g_type_class_peek_parent (class);
-
 	action_class->create_tool_item = create_tool_item;
 	action_class->connect_proxy = connect_proxy;
 	action_class->disconnect_proxy = disconnect_proxy;
 }
+
+static void
+ephy_go_action_init (EphyGoAction *action)
+{
+        /* Empty, needed for G_DEFINE_TYPE macro */
+}
+
